package Staartvin.SimpleRegister.FileHandling;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Level;

import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;

import Staartvin.SimpleRegister.SimpleRegister;

public class MessagesFile {

	private SimpleRegister plugin;

	public MessagesFile(SimpleRegister plugin) {
		this.plugin = plugin;
	}

	private File messages;
	private YamlConfiguration messagesConfig;

	// Messages.yml
	public void reloadMessagesConfig() {
		if (messages == null) {
			messages = new File(plugin.getDataFolder(), "messages.yml");
		}
		messagesConfig = YamlConfiguration.loadConfiguration(messages);

		// Look for defaults in the jar
		InputStream defConfigStream = plugin.getResource("messages.yml");
		if (defConfigStream != null) {
			YamlConfiguration defConfig = YamlConfiguration
					.loadConfiguration(defConfigStream);
			messagesConfig.setDefaults(defConfig);
		}
	}

	private FileConfiguration getMessagesConfig() {
		if (messagesConfig == null) {
			this.reloadMessagesConfig();
		}
		return messagesConfig;
	}

	public void saveMessagesConfig() {
		if (messagesConfig == null || messages == null) {
			return;
		}
		try {
			getMessagesConfig().save(messages);
		} catch (IOException ex) {
			plugin.getLogger().log(Level.SEVERE,
					"Could not save config to " + messages, ex);
		}
	}

	public void loadMessages() {
		reloadMessagesConfig();
		// Load messages
		messagesConfig.options().header(
				"Messages SimpleRegister v"
						+ plugin.getDescription().getVersion() + " Config");
		messagesConfig.addDefault("REGISTER_LINE_1",
				"Hi 9%player%f, you're about to register for 6%servername%");
		messagesConfig.addDefault("REGISTER_LINE_2",
				"7Are you sure you want to register? Type yes or no.");
		messagesConfig.addDefault("REGISTER_LINE_3",
				"cYou can stop at any time by typing 'cancel' or 'stop'");
		messagesConfig.addDefault("REGISTER_NO_LINE_1",
				"cYou have answered no.");
		messagesConfig.addDefault("REGISTER_STOP_REGISTRATION",
				"cYou have stopped the registration!");
		messagesConfig
				.addDefault("REGISTER_YES_LINE_1",
						"aYou have answered yes, we will now proceed to the first question.");
		messagesConfig.addDefault("REGISTER_ANSWER",
				"aYour answer: 6%answer%");
		messagesConfig.addDefault("REGISTER_THANK_YOU",
				"aThank you for registering!");
		messagesConfig.addDefault("REGISTER_DONE_LINE_2",
				"eYour application can be viewed any time now!");
		messagesConfig
				.addDefault("REGISTER_DONE_LINE_3",
						"cTo get the status of your application, type '/sr app view %player%'.");
		messagesConfig.addDefault("NEW_APP_FILED_NOTICE",
				"c%player% has filed a new application!");
		messagesConfig.addDefault("ALREADY_REGISTERED",
				"cYou have already registered!");
		messagesConfig.addDefault("ACCEPT_APPLICATION",
				"aYou've accepted the app of 6%player%");
		messagesConfig.addDefault("DECLINE_APPLICATION",
				"aYou've declined the app of 6%player%");
		messagesConfig.addDefault("CANNOT_FIND_APPLICATION_BECAUSE_NO_PENDING",
				"c%player% does not have a pending app.");
		messagesConfig.addDefault("ALREADY_ACCEPTED",
				"aYour application has already been accepted.");
		messagesConfig.addDefault("OTHER_ALREADY_ACCEPTED",
				"cThe app of %player% has already been accepted.");
		messagesConfig.addDefault("OTHER_NOT_REGISTERED_YET",
				"c%player% has not yet registered!");
		messagesConfig.addDefault("NOT_REGISTERED_YET",
				"cYou haven't registered yet! Type '/register' to register!");
		messagesConfig.addDefault("ALREADY_DECLINED",
				"cThe app of %player% has already been declined!");
		messagesConfig.addDefault("DELETE_APPLICATION",
				"aYou have deleted the app of %player%");
		messagesConfig.addDefault("NOTICE_PLAYER_OF_PENDING_APPLICATIONS",
				"cThere are %amount% application(s) open.");

		getMessagesConfig().options().copyDefaults(true);
		saveMessagesConfig();
	}

	public enum configMessages {
		REGISTER_LINE_1, REGISTER_LINE_2, REGISTER_LINE_3, REGISTER_NO_LINE_1, REGISTER_STOP_REGISTRATION, REGISTER_YES_LINE_1, REGISTER_ANSWER, REGISTER_THANK_YOU, REGISTER_DONE_LINE_2, REGISTER_DONE_LINE_3, NEW_APP_FILED_NOTICE, ALREADY_REGISTERED, ACCEPT_APPLICATION, DECLINE_APPLICATION, CANNOT_FIND_APPLICATION_BECAUSE_NO_PENDING, ALREADY_ACCEPTED, OTHER_ALREADY_ACCEPTED, NOT_REGISTERED_YET, OTHER_NOT_REGISTERED_YET, ALREADY_DECLINED, DELETE_APPLICATION, NOTICE_PLAYER_OF_PENDING_APPLICATIONS
	}

	public String getMessage(configMessages message, String playerName,
			String answer) {
		String realAnswer;
		
		if (answer != null) {
			realAnswer = answer;
		}
		else {
			realAnswer = "";
		}
		String configMessage = "";
		String serverName = plugin.getConfig().getString("Servername");
		String enumString = message.toString();
		int amountOfPendingApplications = plugin.playersConfig.getStringList("PendingApplications").size();

		configMessage = getMessagesConfig().getString(enumString);
		configMessage = configMessage.replace("%player%", playerName)
				.replace("%servername%", serverName)
				.replace("%answer%", realAnswer)
				.replace("%amount%", amountOfPendingApplications + "");
		return configMessage;
	}
}
