package Staartvin.SimpleRegister;

import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;

import Staartvin.SimpleRegister.Commands.AcceptCommand;
import Staartvin.SimpleRegister.Commands.DeclineCommand;
import Staartvin.SimpleRegister.Commands.DeleteCommand;
import Staartvin.SimpleRegister.Commands.HelpCommand;
import Staartvin.SimpleRegister.Commands.PendingCommand;
import Staartvin.SimpleRegister.Commands.ViewCommand;

public class SimpleRegisterCommandExecutor implements CommandExecutor {

	private SimpleRegister plugin;
	private AcceptCommand acceptCommand;
	private DeclineCommand declineCommand;
	private ViewCommand viewCommand;
	private PendingCommand pendingCommand;
	private HelpCommand helpCommand;
	private DeleteCommand delCommand;

	public SimpleRegisterCommandExecutor(SimpleRegister plugin) {
		this.plugin = plugin;
		acceptCommand = new AcceptCommand(plugin);
		declineCommand = new DeclineCommand(plugin);
		viewCommand = new ViewCommand(plugin);
		pendingCommand = new PendingCommand(plugin);
		helpCommand = new HelpCommand(plugin);
		delCommand = new DeleteCommand(plugin);
	}

	public boolean onCommand(final CommandSender sender, Command cmd,
			String commandLabel, String[] args) {
		if (cmd.getName().equalsIgnoreCase("register")) {
			plugin.messages.message(sender);
			return true;
		} else if (cmd.getName().equalsIgnoreCase("accept")) {
			return acceptCommand.onCommand(sender, cmd, commandLabel,
					args);
		} else if (cmd.getName().equalsIgnoreCase("deny")) {
			return declineCommand.onCommand(sender, cmd, commandLabel,
					args);
		} else if (cmd.getName().equalsIgnoreCase("view")) {
			return viewCommand
					.onCommand(sender, cmd, commandLabel, args);
		} else if (cmd.getName().equalsIgnoreCase("applications")) {
			return pendingCommand.onCommand(sender, cmd, commandLabel,
					args);
		} else if (cmd.getName().equalsIgnoreCase("simpleregister")
				|| cmd.getName().equalsIgnoreCase("sr")) {
			if (args.length == 0) {
				sender.sendMessage(ChatColor.BLUE
						+ "-----------------------------------------------------");
				sender.sendMessage(ChatColor.GOLD + "Developed by: "
						+ ChatColor.GRAY + "Staartvin");
				sender.sendMessage(ChatColor.GOLD + "Version: "
						+ ChatColor.GRAY + plugin.getDescription().getVersion());
				sender.sendMessage(ChatColor.YELLOW
						+ "Type /sr help for a list of commands.");
				return true;
			} else if (args.length == 1) {
				if (args[0].equalsIgnoreCase("register")) {
					if (!sender.hasPermission("simpleregister.register")) {
						sender.sendMessage(ChatColor.RED
								+ "You don't have the permission to perform this command!");
						return true;
					}
					plugin.messages.message(sender);
					return true;
				} else if (args[0].equalsIgnoreCase("pending")
						|| args[0].equalsIgnoreCase("applications")
						|| args[0].equalsIgnoreCase("p")
						|| args[0].equalsIgnoreCase("list")
						|| args[0].equalsIgnoreCase("apps")) {
					return pendingCommand.onCommand(sender, cmd,
							commandLabel, args);
				} else if (args[0].equalsIgnoreCase("help")
						|| args[0].equalsIgnoreCase("commands")) {
					return helpCommand.onCommand(sender, cmd, commandLabel, args);
				} else if (args[0].equalsIgnoreCase("reload")) {
					if (!sender.hasPermission("simpleregister.reload")) {
						sender.sendMessage(ChatColor.RED
								+ "You don't have the permission to perform this command!");
						return true;
					}
					sender.sendMessage(ChatColor.BLUE
							+ "-----------------------------------------------------");
					// Reload configuration files
					sender.sendMessage(ChatColor.GREEN + "Reloading " + ChatColor.GOLD + "config.yml");
					plugin.reloadConfig();
					plugin.saveConfig();
					
					sender.sendMessage(ChatColor.GREEN + "Reloading " + ChatColor.GOLD + "registrations.yml");
					plugin.loadConfiguration.reloadRegistrationsConfig();
					plugin.loadConfiguration.saveRegistrationsConfig();
					
					sender.sendMessage(ChatColor.GREEN + "Reloading " + ChatColor.GOLD + "messages.yml");
					plugin.messagesFile.reloadMessagesConfig();
					plugin.messagesFile.saveMessagesConfig();
					
					sender.sendMessage(ChatColor.GREEN + "Successfully reloaded files.");
					return true;
				}
			} else if (args.length == 3) {
				if (args[0].equalsIgnoreCase("application")
						|| args[0].equalsIgnoreCase("applications")
						|| args[0].equalsIgnoreCase("a")
						|| args[0].equalsIgnoreCase("app")) {
					if (args[1].equalsIgnoreCase("accept")
							|| args[1].equalsIgnoreCase("a")
							|| args[1].equalsIgnoreCase("yes")
							|| args[1].equalsIgnoreCase("ok")) {
						return acceptCommand.onCommand(sender, cmd,
								commandLabel, args);
					} else if (args[1].equalsIgnoreCase("decline")
							|| args[1].equalsIgnoreCase("d")
							|| args[1].equalsIgnoreCase("no")
							|| args[1].equalsIgnoreCase("reject")
							|| args[1].equalsIgnoreCase("deny")) {
						return declineCommand.onCommand(sender, cmd,
								commandLabel, args);
					} else if (args[1].equalsIgnoreCase("view")
							|| args[1].equalsIgnoreCase("v")) {
						return viewCommand.onCommand(sender, cmd,
								commandLabel, args);
					} else if (args[1].equalsIgnoreCase("delete")
							|| args[1].equalsIgnoreCase("del")) {
						return delCommand.onCommand(sender, cmd,
								commandLabel, args);
					}
				}
			}
		}
		sender.sendMessage(ChatColor.RED
				+ "Command not recognized! Use '/sr help' to see a list of commands!");
		return true;

	}
}